:orphan:

.. title:: Matplotlib documentation

.. module:: matplotlib

Matplotlib documentation 
------------------------

Release: |release|

Matplotlib is a comprehensive library for creating static, animated,
and interactive visualizations in Python.

Learn
=====
      
- :doc:`Quick-start Guide <tutorials/introductory/usage>`
- Basic :doc:`Plot Types <plot_types/index>` and :doc:`Example Gallery <gallery/index>`
- `Introductory Tutorials <../tutorials/index.html#introductory>`_
- :doc:`External Learning Resources <resources/index>`
      
Reference
=========

- :doc:`API Reference <api/index>`

  - :doc:`pyplot API <api/pyplot_summary>`: top-level interface to create 
    Figures (`.pyplot.figure`) and Subplots (`.pyplot.subplots`, 
    `.pyplot.subplot_mosaic`)
  - :doc:`Axes API <api/axes_api>` for *most* plotting methods
  - :doc:`Figure API <api/figure_api>` for figure-level methods

- :doc:`Extra Toolkits <api/toolkits/index>`

How-tos
=======

- :doc:`Installation Guide <users/installing>`
- :doc:`Contributing to Matplotlib <devel/index>`
- :doc:`Matplotlib FAQ <faq/index>`

Understand how Matplotlib works
===============================

- Many of the :doc:`Tutorials <tutorials/index>` have explanatory material
